@@ -13,8 +13,10 @@ test_that("tidy.mle2", {
     y = c(26, 17, 13, 12, 20, 5, 9, 8, 5, 4, 8)
   )
 
-  fit <- bbmle::mle2(y ~ dpois(lambda = ymean),
-    start = list(ymean = 10), data = df
+  fit <- bbmle::mle2(
+    y ~ dpois(lambda = ymean),
+    start = list(ymean = 10),
+    data = df
   )
 
   td <- tidy(fit, conf.int = TRUE)
